/*! 
    \file light.h
    \brief Handles Lights.

    A Light is one of the more important things in a 3D-environment,
    without it one sees nothing :)
    It is here for diffuse-, specular- and Bump-Mappings.
*/

#ifndef _LIGHT_H
#define _LIGHT_H

#include "world_entity.h"
#include "glincl.h"

// FORWARD DEFINITIONS //
class Vector;

//! A class that handles Lights
/**
   A Light is a source that emits light rays (photons)
*/
class Light : public WorldEntity 
{
  

 public:
  Light(void);
  Light(Vector position);
  ~Light(void);

  // set Attributes
  void setPosition(Vector position);
  void setDiffuseColor(GLfloat r, GLfloat g, GLfloat b);
  void setSpecularColor(GLfloat r, GLfloat g, GLfloat b);
  
  // get Attributes
  Vector getPosition(void);
 private:
  GLfloat lightPosition[4];   //!< The Position of this Light
  GLfloat lmodelAmbient[4];   //!< The general Ambient Color
  GLfloat diffuseColor[4];    //!< The Diffuse Color this Light emmits
  GLfloat specularColor[4];   //!< The specular Color of this Light

  void init();
};

#endif /* _LIGHT_H */
